@@ -1,6 +1,6 @@
 '''cr_content_hub.py: click content-hub checks'''
 #
-# Copyright (C) 2014 Canonical Ltd.
+# Copyright (C) 2014-2015 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,21 +16,22 @@
 
 from __future__ import print_function
 
-from clickreviews.cr_common import ClickReview, error, open_file_read, msg
+from clickreviews.cr_common import ClickReview, error, open_file_read
 import json
 import os
 
 
 class ClickReviewContentHub(ClickReview):
     '''This class represents click lint reviews'''
-    def __init__(self, fn):
+    def __init__(self, fn, overrides=None):
         peer_hooks = dict()
         my_hook = 'content-hub'
         peer_hooks[my_hook] = dict()
         peer_hooks[my_hook]['allowed'] = ClickReview.app_allowed_peer_hooks
         peer_hooks[my_hook]['required'] = []
 
-        ClickReview.__init__(self, fn, "content_hub", peer_hooks=peer_hooks)
+        ClickReview.__init__(self, fn, "content_hub", peer_hooks=peer_hooks,
+                             overrides=overrides)
 
         self.valid_keys = ['destination', 'share', 'source']
 
