@@ -24,7 +24,7 @@ import re
 from clickreviews.frameworks import Frameworks
 from clickreviews.cr_common import ClickReview, open_file_read, cmd
 
-CONTROL_FILE_NAMES = ["control", "manifest", "md5sums", "preinst"]
+CONTROL_FILE_NAMES = ["control", "manifest", "preinst"]
 MINIMUM_CLICK_FRAMEWORK_VERSION = "0.4"
 
 
@@ -33,7 +33,9 @@ class ClickReviewLint(ClickReview):
 
     def __init__(self, fn, overrides=None):
         '''Set up the class.'''
-        ClickReview.__init__(self, fn, "lint")
+        ClickReview.__init__(self, fn, "lint", overrides=overrides)
+        if not self.is_snap and "md5sums" not in CONTROL_FILE_NAMES:
+            CONTROL_FILE_NAMES.append("md5sums")
         self.control_files = dict()
         self._list_control_files()
         # Valid values for Architecture in DEBIAN/control. Note:
@@ -93,15 +95,13 @@ class ClickReviewLint(ClickReview):
                             'bin-path',
                             'content-hub',
                             'desktop',
-                            'framework',
                             'pay-ui',
                             'push-helper',
                             'scope',
                             'snappy-systemd',
                             'urls']
 
-        self.redflagged_hooks = ['framework',
-                                 'pay-ui',
+        self.redflagged_hooks = ['pay-ui',
                                  'apparmor-profile',
                                  ]
 
@@ -111,17 +111,12 @@ class ClickReviewLint(ClickReview):
         # - oem
         self.snappy_valid_types = ['app',
                                    'framework',
-                                   # 'framework-policy',  # TBI
-                                   # 'oem',               # TBI
+                                   'oem',
                                    ]
         self.snappy_redflagged_types = ['framework',
-                                        # 'oem',           # TBI
+                                        'oem',  # TBD
                                         ]
 
-        if overrides is None:
-            overrides = {}
-        self.overrides = overrides
-
     def _list_control_files(self):
         '''List all control files with their full path.'''
         for i in CONTROL_FILE_NAMES:
@@ -263,7 +258,8 @@ class ClickReviewLint(ClickReview):
         n = 'control_description_match'
         s = 'OK'
         if 'title' in self.manifest:
-            if control['Description'] != self.manifest['title']:
+            if control['Description'].strip() != \
+               self.manifest['title'].strip():
                 t = 'error'
                 s = "Description=%s does not match manifest title=%s" % \
                     (control['Description'], self.manifest['title'])
@@ -343,6 +339,10 @@ exit 1
 
     def check_hooks(self):
         '''Check click manifest hooks'''
+        #  oem snaps don't have a hooks entry
+        if self.is_snap_oem:
+            return
+
         # Some checks are already handled in
         # cr_common.py:_verify_manifest_structure()
 
@@ -436,6 +436,10 @@ exit 1
 
     def check_hooks_unknown(self):
         '''Check if have any unknown hooks'''
+        #  oem snaps don't have a hooks entry
+        if self.is_snap_oem:
+            return
+
         t = 'info'
         n = 'unknown hooks'
         s = 'OK'
@@ -703,39 +707,6 @@ exit 1
                 click_package_bn
         self._add_result(t, n, s)
 
-        #  handle $pkgname.click or $pkgname.snap
-        if self.click_package.endswith('.snap'):
-            pkgname = tmp[0].partition('.snap')[0]
-        else:
-            pkgname = tmp[0].partition('.click')[0]
-        t = 'info'
-        n = 'package_filename_pkgname_match'
-        s = 'OK'
-        l = None
-        if pkgname != self.click_pkgname:
-            if pkgname.startswith('com.ubuntu.snappy.') or \
-               click_package_bn.startswith('com.ubuntu.snappy.'):
-                s = "OK (store snappy workaround)"
-            else:
-                t = 'error'
-                s = "'%s' != '%s' from DEBIAN/control" % (pkgname,
-                                                          self.click_pkgname)
-                l = 'http://askubuntu.com/questions/417361/what-does-lint-package-filename-pkgname-match-mean'
-        self._add_result(t, n, s, l)
-
-        # check if namespaces matches with filename
-        t = 'info'
-        n = 'package_filename_matches_namespace'
-        s = 'OK'
-        namespace_bits = self.click_pkgname.split('.')[:-1]
-        len_namespace = len(namespace_bits)
-        pkgname_bits = pkgname.split('.')[:len_namespace]
-        if namespace_bits != pkgname_bits:
-            t = 'error'
-            s = "Package name '%s' does not match namespace '%s'." % \
-                ('.'.join(namespace_bits), '.'.join(pkgname_bits))
-        self._add_result(t, n, s)
-
         t = 'info'
         n = 'package_filename_version_match'
         s = 'OK'
@@ -790,9 +761,13 @@ exit 1
             else:
                 arch = tmp[2].partition('.click')[0]
             if arch != self.click_arch:
-                t = 'error'
-                s = "'%s' != '%s' from DEBIAN/control" % (arch,
-                                                          self.click_arch)
+                if arch == 'all' and self.click_arch == 'multi':
+                    # The store creates filenames for fat packages with _all
+                    pass
+                else:
+                    t = 'error'
+                    s = "'%s' != '%s' from DEBIAN/control" % (arch,
+                                                              self.click_arch)
         else:
             t = 'warn'
             s = "could not determine architecture from '%s'" % \
