@@ -1,6 +1,6 @@
 '''cr_scope.py: click scope'''
 #
-# Copyright (C) 2014 Canonical Ltd.
+# Copyright (C) 2014-2015 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 from __future__ import print_function
 
-from clickreviews.cr_common import ClickReview, error, msg
+from clickreviews.cr_common import ClickReview, error
 import codecs
 import configparser
 import os
@@ -30,14 +30,15 @@ KNOWN_SECTIONS = set(["ScopeConfig", "Appearance"])
 
 class ClickReviewScope(ClickReview):
     '''This class represents click lint reviews'''
-    def __init__(self, fn):
+    def __init__(self, fn, overrides=None):
         peer_hooks = dict()
         my_hook = 'scope'
         peer_hooks[my_hook] = dict()
         peer_hooks[my_hook]['allowed'] = ClickReview.scope_allowed_peer_hooks
         peer_hooks[my_hook]['required'] = ['apparmor']
 
-        ClickReview.__init__(self, fn, "scope", peer_hooks=peer_hooks)
+        ClickReview.__init__(self, fn, "scope", peer_hooks=peer_hooks,
+                             overrides=overrides)
 
         self.scopes = dict()
         for app in self.manifest['hooks']:
