@@ -46,6 +46,8 @@ TEST_ACCOUNTS_SERVICE = dict()
 TEST_PUSH_HELPER = dict()
 TEST_BIN_PATH = dict()
 TEST_FRAMEWORK = dict()
+TEST_FRAMEWORK_POLICY = dict()
+TEST_FRAMEWORK_POLICY_UNKNOWN = []
 TEST_SNAPPY_SYSTEMD = dict()
 
 
@@ -198,6 +200,16 @@ def _extract_framework(self, app):
     return ("%s.framework" % app, TEST_FRAMEWORK[app])
 
 
+def _extract_framework_policy(self):
+    '''Pretend we found the framework policy files'''
+    return (TEST_FRAMEWORK_POLICY, TEST_FRAMEWORK_POLICY_UNKNOWN)
+
+
+def _has_framework_in_metadir(self):
+    '''Pretend we found the framework file'''
+    return True
+
+
 def _extract_systemd(self, app):
     '''Pretend we found the systemd file'''
     return ("%s.snappy-systemd" % app, TEST_SNAPPY_SYSTEMD[app])
@@ -312,6 +324,12 @@ patches.append(patch(
 patches.append(patch(
     'clickreviews.cr_framework.ClickReviewFramework._extract_framework',
     _extract_framework))
+patches.append(patch(
+    'clickreviews.cr_framework.ClickReviewFramework._extract_framework_policy',
+    _extract_framework_policy))
+patches.append(patch(
+    'clickreviews.cr_framework.ClickReviewFramework._has_framework_in_metadir',
+    _has_framework_in_metadir))
 
 # systemd overrides
 patches.append(patch(
@@ -399,6 +417,8 @@ class TestClickReview(TestCase):
         self.test_push_helper = dict()
         self.test_bin_path = dict()
         self.test_framework = dict()
+        self.test_framework_policy = dict()
+        self.test_framework_policy_unknown = []
         self.test_systemd = dict()
         for app in self.test_manifest["hooks"].keys():
             # setup security manifest for each app
@@ -444,6 +464,10 @@ class TestClickReview(TestCase):
             # Reset to no framework entries in manifest
             self.set_test_framework(app, None, None)
 
+            # Reset to no framework entries in manifest
+            self.set_test_framework_policy(None)
+            self.set_test_framework_policy_unknown([])
+
             # Reset to no systemd entries in manifest
             self.set_test_systemd(app, None, None)
 
@@ -463,6 +487,8 @@ class TestClickReview(TestCase):
         self._update_test_push_helper()
         self._update_test_bin_path()
         self._update_test_framework()
+        self._update_test_framework_policy()
+        self._update_test_framework_policy_unknown()
         self._update_test_systemd()
 
         # webapps manifests (leave empty for now)
@@ -617,6 +643,14 @@ class TestClickReview(TestCase):
                 "%s.framework" % TEST_FRAMEWORK[app]
         self._update_test_manifest()
 
+    def _update_test_framework_policy(self):
+        global TEST_FRAMEWORK_POLICY
+        TEST_FRAMEWORK_POLICY = self.test_framework_policy
+
+    def _update_test_framework_policy_unknown(self):
+        global TEST_FRAMEWORK_POLICY_UNKNOWN
+        TEST_FRAMEWORK_POLICY_UNKNOWN = self.test_framework_policy_unknown
+
     def _update_test_systemd(self):
         global TEST_SNAPPY_SYSTEMD
         TEST_SNAPPY_SYSTEMD = dict()
@@ -851,7 +885,44 @@ class TestClickReview(TestCase):
 
     def set_test_bin_path(self, app, value):
         '''Set bin-path entries. If value is None, remove bin-path from
-           manifest'''
+           manifest and yaml. If app != value, set 'exec' in the yaml
+
+           Note the click manifest and the package.yaml use different
+           storage types. pkg_yaml['binaries'] is a list of dictionaries where
+           manifest['hooks'] is a dictionary of dictionaries. This function
+           sets the manifest entry and then a yaml entry with 'name' and 'exec'
+           fields.
+
+             manifest['hooks'][app]['bin-path'] = value
+             pkg_yaml['binaries'][*]['name'] = app
+             pkg_yaml['binaries'][*]['exec'] = value
+        '''
+
+        # Update the package.yaml
+        if value is None:
+            if 'binaries' in self.test_pkg_yaml:
+                for b in self.test_pkg_yaml['binaries']:
+                    if 'name' in b and b['name'] == app:
+                        self.test_pkg_yaml['binaries'].remove(b)
+                        break
+        else:
+            found = False
+            if 'binaries' in self.test_pkg_yaml:
+                for b in self.test_pkg_yaml['binaries']:
+                    if 'name' in b and b['name'] == app:
+                        found = True
+                        break
+            if not found:
+                if 'binaries' not in self.test_pkg_yaml:
+                    self.test_pkg_yaml['binaries'] = []
+                if value == app:
+                    self.test_pkg_yaml['binaries'].append({'name': app})
+                else:
+                    self.test_pkg_yaml['binaries'].append({'name': app,
+                                                           'exec': value})
+        self._update_test_pkg_yaml()
+
+        # Update the click manifest (we still support click format)
         if value is None:
             if app in self.test_bin_path:
                 self.test_bin_path.pop(app)
@@ -859,6 +930,8 @@ class TestClickReview(TestCase):
             if app not in self.test_bin_path:
                 self.test_bin_path[app] = dict()
             self.test_bin_path[app] = value
+
+        # Now update TEST_BIN_PATH
         self._update_test_bin_path()
 
     def set_test_framework(self, app, key, value):
@@ -876,9 +949,68 @@ class TestClickReview(TestCase):
             self.test_framework[app][key] = value
         self._update_test_framework()
 
+    def set_test_framework_policy(self, policy_dict=None):
+        '''Set framework policy'''
+        if policy_dict is None:  # Reset
+            self.test_framework_policy = dict()
+            for i in ['apparmor', 'seccomp']:
+                self.test_framework_policy[i] = dict()
+                for j in ['templates', 'policygroups']:
+                    self.test_framework_policy[i][j] = dict()
+                    for k in ['-common', '-reserved']:
+                        n = "%s%s" % (j.rstrip('s'), k)
+                        self.test_framework_policy[i][j][n] = \
+                            '''# Description: %s
+# Usage: %s
+''' % (n, k.lstrip('-'))
+        else:
+            self.test_framework_policy = policy_dict
+        self._update_test_framework_policy()
+
+    def set_test_framework_policy_unknown(self, unknown=[]):
+        '''Set framework policy unknown'''
+        self.test_framework_policy_unknown = unknown
+        self._update_test_framework_policy_unknown()
+
     def set_test_systemd(self, app, key, value):
-        '''Set systemd entries. If key is None, remove hook, if value is None,
-           remove key'''
+        '''Set systemd entries. If key is None, snappy-systemd from manifest
+           and yaml.
+
+           Note the click manifest and the package.yaml use different
+           storage types. pkg_yaml['services'] is a list of dictionaries where
+           manifest['hooks'] is a dictionary of dictionaries. This function
+           sets the manifest entry and then a yaml entry with 'name' field.
+
+           manifest['hooks'][app]['snappy-systemd'] = <path to yaml>
+           pkg_yaml['services'][*]['name'] = app
+           pkg_yaml['services'][*][key] = value
+        '''
+
+        # Update the package.yaml
+        if key is None:
+            if 'services' in self.test_pkg_yaml:
+                for s in self.test_pkg_yaml['services']:
+                    if 'name' in s and s['name'] == app:
+                        self.test_pkg_yaml['services'].remove(s)
+                        break
+        else:
+            found = False
+            if 'services' in self.test_pkg_yaml:
+                for s in self.test_pkg_yaml['services']:
+                    if 'name' in s and s['name'] == app:
+                        # Found the entry, so update key/value
+                        s[key] = value
+                        found = True
+                        break
+            # Did not find the entry, so create one
+            if not found:
+                if 'services' not in self.test_pkg_yaml:
+                    self.test_pkg_yaml['services'] = []
+                self.test_pkg_yaml['services'].append({'name': app,
+                                                       key: value})
+        self._update_test_pkg_yaml()
+
+        #  Update the click manifest (we still support click format)
         if key is None:
             if app in self.test_systemd:
                 self.test_systemd.pop(app)
@@ -891,6 +1023,8 @@ class TestClickReview(TestCase):
                     del(self.test_systemd[app][key])
             else:
                 self.test_systemd[app][key] = value
+
+        # Now update TEST_SNAPPY_SYSTEMD
         self._update_test_systemd()
 
     def setUp(self):
@@ -935,6 +1069,10 @@ class TestClickReview(TestCase):
         TEST_BIN_PATH = dict()
         global TEST_FRAMEWORK
         TEST_FRAMEWORK = dict()
+        global TEST_FRAMEWORK_POLICY
+        TEST_FRAMEWORK_POLICY = dict()
+        global TEST_FRAMEWORK_POLICY_UNKNOWN
+        TEST_FRAMEWORK_POLICY_UNKNOWN = []
         global TEST_SNAPPY_SYSTEMD
         TEST_SNAPPY_SYSTEMD = dict()
 
