@@ -221,7 +221,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         c = ClickReviewLint(test_name)
         c.check_package_filename()
         r = c.click_report
-        expected_counts = {'info': None, 'warn': 3, 'error': 3}
+        expected_counts = {'info': None, 'warn': 3, 'error': 1}
         self.check_results(r, expected_counts)
 
     def test_check_package_filename_extra_underscore(self):
@@ -232,27 +232,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         c = ClickReviewLint(test_name)
         c.check_package_filename()
         r = c.click_report
-        expected_counts = {'info': None, 'warn': 2, 'error': 4}
-        self.check_results(r, expected_counts)
-
-    def test_check_package_filename_control_mismatches(self):
-        '''Test check_package_filename() (control mismatches filename)'''
-        self.set_test_control("Package", "test-match")
-        c = ClickReviewLint(self.test_name)
-        c.check_package_filename()
-        r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(r, expected_counts)
-
-    def test_check_package_filename_namespace_mismatches(self):
-        '''Test check_package_filename() (control mismatches filename)'''
-        test_name = "%s_%s_%s.click" % ("com.example.someuser",
-                                        self.test_control['Version'],
-                                        self.test_control['Architecture'])
-        c = ClickReviewLint(test_name)
-        c.check_package_filename()
-        r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 2}
+        expected_counts = {'info': None, 'warn': 2, 'error': 2}
         self.check_results(r, expected_counts)
 
     def test_check_package_filename_version_mismatches(self):
@@ -801,6 +781,17 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
+    def test_check_hooks_type_oem(self):
+        '''Test check_hooks() - type: oem'''
+        self.set_test_manifest("framework", "ubuntu-sdk-13.10")
+        c = ClickReviewLint(self.test_name)
+        c.is_snap_oem = True
+        c.check_hooks()
+        r = c.click_report
+        # oem type has no hooks so these should all be '0'
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_hooks_unknown_nonexistent(self):
         '''Test check_hooks_unknown() - nonexistent'''
         self.set_test_manifest("framework", "ubuntu-sdk-13.10")
@@ -820,6 +811,17 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    def test_check_hooks_unknown_type_oem(self):
+        '''Test check_hooks_unknown() - type: oem'''
+        self.set_test_manifest("framework", "ubuntu-sdk-13.10")
+        c = ClickReviewLint(self.test_name)
+        c.is_snap_oem = True
+        c.check_hooks_unknown()
+        r = c.click_report
+        # oem type has no hooks so these should all be '0'
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_hooks_redflagged_payui(self):
         '''Test check_hooks_redflagged() - pay-ui'''
         self.set_test_manifest("framework", "ubuntu-sdk-13.10")
@@ -1013,24 +1015,13 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
-    def test_snappy_type_framework_policy(self):
-        '''Test check_snappy_type - framework-policy'''
-        self.set_test_pkg_yaml("type", "framework-policy")
-        c = ClickReviewLint(self.test_name)
-        c.check_snappy_type()
-        r = c.click_report
-        # TODO: update this when 'framework-policy' is implemented
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(r, expected_counts)
-
     def test_snappy_type_oem(self):
         '''Test check_snappy_type - oem'''
         self.set_test_pkg_yaml("type", "oem")
         c = ClickReviewLint(self.test_name)
         c.check_snappy_type()
         r = c.click_report
-        # TODO: update this when 'oem' is implemented
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
     def test_snappy_type_redflagged(self):
@@ -1114,7 +1105,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
-    def test_check_icon_empty(self):
+    def test_check_snappy_icon_empty(self):
         '''Test check_snappy_icon() - empty'''
         self.set_test_pkg_yaml("icon", "")
         c = ClickReviewLint(self.test_name)
