@@ -1,6 +1,6 @@
 '''test_cr_security.py: tests for the cr_security module'''
 #
-# Copyright (C) 2013-2014 Canonical Ltd.
+# Copyright (C) 2013-2015 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -934,8 +934,8 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
         # do the test
         c.check_peer_hooks()
         r = c.click_report
-        # We should end up with 2 info
-        expected_counts = {'info': 2, 'warn': 0, 'error': 0}
+        # We should end up with 4 info
+        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
     def test_check_peer_hooks_disallowed(self):
@@ -960,6 +960,71 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
+    def test_check_peer_hooks_disallowed_apparmor_profile(self):
+        '''Test check_peer_hooks() - disallowed (apparmor-profile)'''
+        c = ClickReviewSecurity(self.test_name)
+
+        # create a new hooks database for our peer hooks tests
+        tmp = dict()
+
+        # add our hook
+        tmp["apparmor"] = "foo.apparmor"
+
+        # add something not allowed
+        tmp["apparmor-profile"] = "foo.profile"
+
+        c.manifest["hooks"][self.default_appname] = tmp
+        self._update_test_manifest()
+
+        # do the test
+        c.check_peer_hooks()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
+    def test_check_peer_hooks_aa_profile(self):
+        '''Test check_peer_hooks() - apparmor-profile'''
+        c = ClickReviewSecurity(self.test_name)
+
+        # create a new hooks database for our peer hooks tests
+        tmp = dict()
+
+        # add our hook
+        tmp["apparmor-profile"] = "foo.profile"
+
+        # update the manifest and test_manifest
+        c.manifest["hooks"][self.default_appname] = tmp
+        self._update_test_manifest()
+
+        # do the test
+        c.check_peer_hooks()
+        r = c.click_report
+        # We should end up with 4 info
+        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_peer_hooks_aa_profile_disallowed(self):
+        '''Test check_peer_hooks() - disallowed - apparmor-profile'''
+        c = ClickReviewSecurity(self.test_name)
+
+        # create a new hooks database for our peer hooks tests
+        tmp = dict()
+
+        # add our hook
+        tmp["apparmor-profile"] = "foo.profile"
+
+        # add something not allowed
+        tmp["framework"] = "foo.framework"
+
+        c.manifest["hooks"][self.default_appname] = tmp
+        self._update_test_manifest()
+
+        # do the test
+        c.check_peer_hooks()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
     def test_check_redflag_policy_vendor_ubuntu(self):
         '''Test check_redflag() - policy_vendor - ubuntu'''
         c = ClickReviewSecurity(self.test_name)
@@ -1039,3 +1104,36 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
         report = c.click_report
         expected_counts = {'info': 0, 'warn': 0, 'error': 1}
         self.check_results(report, expected_counts)
+
+    def test_check_apparmor_profile(self):
+        '''Test check_apparmor_profile()'''
+        policy = '''
+###VAR###
+###PROFILEATTACH### {
+  #include <abstractions/base>
+  # Read-only for the install directory
+  @{CLICK_DIR}/@{APP_PKGNAME}/@{APP_VERSION}/**  mrklix,
+}
+'''
+        self.set_test_security_profile(self.default_appname, policy)
+        c = ClickReviewSecurity(self.test_name)
+        c.check_apparmor_profile()
+        report = c.click_report
+        expected_counts = {'info': 5, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_apparmor_profile_missing_var(self):
+        '''Test check_apparmor_profile() - missing ###VAR###'''
+        policy = '''
+###PROFILEATTACH### {
+  #include <abstractions/base>
+  # Read-only for the install directory
+  @{CLICK_DIR}/@{APP_PKGNAME}/@{APP_VERSION}/**  mrklix,
+}
+'''
+        self.set_test_security_profile(self.default_appname, policy)
+        c = ClickReviewSecurity(self.test_name)
+        c.check_apparmor_profile()
+        report = c.click_report
+        expected_counts = {'info': None, 'warn': 1, 'error': 0}
+        self.check_results(report, expected_counts)
